## bootstrap CPo results, including parametric model for inflation
## Table 2, third panel
## Table 6

## differences with CPo
## - regressors are PCs (but inflation trend is identical)
## - yield maturities up to 10 instead of 20 years
## - dep.var is cumulative return (consistent with reverse regression)

rm(list=ls())
source("R/robust_fns.r")
source("R/var_fns.r")
set.seed(616)
M <- 5000

df <- getOwnCPoData()
estSize <- TRUE

## use this instead to get results for 1985-2015 sample
## df <- getOwnCPoData(198501, 201512)
## estSize <- FALSE

## write.csv(df, "data/export/cpo.csv", row.names=FALSE)
## stop()

X1.names <- c("PC1", "PC2", "PC3")
X2.names <- "trend"
fmla1 <- xr.avg ~ PC1 + PC2 + PC3
fmla2 <- xr.avg ~ PC1 + PC2 + PC3 + trend

## Figure 3
plotSubsampleBetas(fmla2, df, q=8, plot.mode=0, filename="subsample_betas_cpo")

## dgp <- getCPoBootDGP(X1.names, X2.names, df)
dgp <- getCPoBootDGP(X1.names, X2.names, df)

## to avoid trends:
## cat("# initializing at unconditional mean\n")
## dgp$X1.init <- dgp$EX1
## dgp$X2.init <- dgp$EX2

## look at AR(1):
## rval <- ar.ols(df$trend, aic=FALSE, order.max=1, demean=FALSE, intercept=TRUE)
## mu2 <- rval$x.intercept
## sig2 <- sqrt(rval$var.pred)
## rho2 <- rval$ar[,,]
## print(mu2/sig2)
## df$trend[1]/(mu2/(1-rho2))

## for restricted model
tbl1 <- matrix(NA, 3, 4)
rownames(tbl1) <- c("Coefficient", "RR t-statistic", "RR p-value")
colnames(tbl1) <- c("PC1", "PC2", "PC3", "trend")
mod1 <- lm(fmla1, df)
tbl1[1, 1:3] <- mod1$coef[-1]
rval <- RevRegDelta(c("PC1", "PC2", "PC3"), df)
tbl1[2, 1:3] <- rval$tstat
tbl1[3, 1:3] <- pt(abs(rval$tstat), mod1$df, lower.tail=FALSE)*2

### bootstrap simulations and results
rval1 <- bootstrapTestRR(fmla1, fmla2, df, dgp, M=M, estIMSize=estSize)
rval1$tblSize[,1:3] <- NA
tbl2 <- rval1$tblCoef

if (estSize) {
    tbl2 <- rbind(tbl2, rval1$tblSize)

    ## Power
    rval2 <- bootstrapTestRR(fmla1, fmla2, df, dgp, M=M, H0=FALSE, estIMSize=TRUE)
    tblPower <- rval2$tblSize
    rownames(tblPower) <- c("Power HAC", "Power RR", "Power IM q=8", "Power IM q=16")
    tbl2 <- rbind(tbl2, tblPower)
}

## R^2 table
print(round(rval1$tblR2, digi=2))

cat("Data        ", sprintf("& %3.2f ", rval1$tblR2[1,c(1,3,5)]), "\\\\ \n")
cat("Bootstrap   ", sprintf("& %3.2f ", rval1$tblR2[2,c(1,3,5)]), "\\\\ \n")
cat(sprintf("& (%3.2f, %3.2f)", rval1$tblR2[3,c(1,3,5)], rval1$tblR2[3,c(2,4,6)]), "\\\\ \n")

## coefficients & inference
print(round(rbind(tbl1, tbl2), 3))
if (estSize) {
    tbl2 <- tbl2[c(1,4,5,8,9,10,11,13,14,15, 18,19),]
} else {
    tbl2 <- tbl2[c(1,4,5,8,9,10,11),]
}

printLatexTbl(tbl1)
printLatexTbl(tbl2)
